summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_function_dispatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/extensions/extension_function_dispatcher.h')
-rw-r--r--chrome/browser/extensions/extension_function_dispatcher.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/chrome/browser/extensions/extension_function_dispatcher.h b/chrome/browser/extensions/extension_function_dispatcher.h
index 9e80fca..9261a89 100644
--- a/chrome/browser/extensions/extension_function_dispatcher.h
+++ b/chrome/browser/extensions/extension_function_dispatcher.h
@@ -19,6 +19,7 @@ struct ExtensionHostMsg_Request_Params;
namespace content {
class BrowserContext;
+class RenderFrameHost;
class RenderViewHost;
class WebContents;
}
@@ -106,12 +107,14 @@ class ExtensionFunctionDispatcher
// Message handlers.
// The response is sent to the corresponding render view in an
// ExtensionMsg_Response message.
+ // TODO (jam): convert all callers to use RenderFrameHost.
void Dispatch(const ExtensionHostMsg_Request_Params& params,
content::RenderViewHost* render_view_host);
// |callback| is called when the function execution completes.
void DispatchWithCallback(
const ExtensionHostMsg_Request_Params& params,
- content::RenderViewHost* render_view_host,
+ content::RenderFrameHost* render_frame_host,
const ExtensionFunction::ResponseCallback& callback);
// Called when an ExtensionFunction is done executing, after it has sent
@@ -156,6 +159,12 @@ class ExtensionFunctionDispatcher
static void SendAccessDenied(
const ExtensionFunction::ResponseCallback& callback);
+ void DispatchWithCallbackInternal(
+ const ExtensionHostMsg_Request_Params& params,
+ content::RenderViewHost* render_view_host,
+ content::RenderFrameHost* render_frame_host,
+ const ExtensionFunction::ResponseCallback& callback);
+
content::BrowserContext* browser_context_;
Delegate* delegate_;
@@ -106,12 +107,14 @@ class ExtensionFunctionDispatcher
void Dispatch(const ExtensionHostMsg_Request_Params& params,
content::RenderViewHost* render_view_host);
- // |callback| is called when the function execution completes.
+ // Dispatch an extension function and calls |callback| when the execution
+ // completes.
void DispatchWithCallback(
const ExtensionHostMsg_Request_Params& params,